Crate hv_stampede

Crate hv_stampede 

Heavy Stampede - a friendly herd of bumpalos, with extra features

This crate builds on and reexports most things from the bumpalo crate. In implementation and usage, it is very similar to the bumpalo-herd crate, but supports some operations that Herd does not:

Modules

boxed
A pointer type for bump allocation.
collections
Collection types that allocate inside a Bump arena.

Macros

format
Like the format! macro, but for creating bumpalo::collections::Strings.
vec
Creates a Vec containing the arguments.

Structs

Bump
An arena to bump allocate into.
BumpPool
A thread-safe pool of Bumps (provided as PooledBumps). Internally, this is two pools; the “ready” pool of Bumps which do not yet have any objects tied to their lifetimes, and the “shunned” pool of Bumps which were detached using PooledBump::detach and must not be allocated from or destroyed until the entire pool is .reset().
Chunk
ChunkIntoIter
ChunkIter
An iterator over each chunk of allocated memory that an arena has bump allocated into.
ChunkRawIter
An iterator over raw pointers to chunks of allocated memory that this arena has bump allocated into.
PooledBump
A Bump which was allocated from a BumpPool.

Enums

AllocOrInitError
An error returned from Bump::try_alloc_try_with.