Heavy Stampede - a friendly herd of bumpalos, with extra features
This crate builds on and reexports most things from the bumpalo crate. In implementation and
usage, it is very similar to the bumpalo-herd crate, but supports some operations that Herd
does not:
BumpPoolsupports temporarily detaching aBumpfrom the pool throughPooledBump::detach, locking it to the thread it was detached in until it is dropped and returned to the pool.PooledBump::as_bump_unbound, unsafe access to the managedBumpinside.
Modules
- boxed
- A pointer type for bump allocation.
- collections
- Collection types that allocate inside a
Bumparena.
Macros
- format
- Like the
format!macro, but for creatingbumpalo::collections::Strings. - vec
- Creates a
Veccontaining the arguments.
Structs
- Bump
- An arena to bump allocate into.
- Bump
Pool - A thread-safe pool of
Bumps (provided asPooledBumps). Internally, this is two pools; the “ready” pool ofBumps which do not yet have any objects tied to their lifetimes, and the “shunned” pool ofBumps which were detached usingPooledBump::detachand must not be allocated from or destroyed until the entire pool is.reset(). - Chunk
- Chunk
Into Iter - Chunk
Iter - An iterator over each chunk of allocated memory that an arena has bump allocated into.
- Chunk
RawIter - An iterator over raw pointers to chunks of allocated memory that this arena has bump allocated into.
- Pooled
Bump - A
Bumpwhich was allocated from aBumpPool.
Enums
- Alloc
OrInit Error - An error returned from
Bump::try_alloc_try_with.